@@ -27,6 +27,7 @@ const (
 	External       = "external"
 	Exclude        = "exclude"
 	Include        = "include"
+	Reading        = "reading"
 
 	QueueConstructAsFlagName  = "queue-construct-as"
 	QueueConstructAsFlagAlias = "as"
@@ -80,6 +81,12 @@ func NewFlags(opts *Options, prefix flags.Prefix) cli.Flags {
 			Destination: &opts.Include,
 			Usage:       "Display include configurations in the results (only when using --format=json).",
 		}),
+		flags.NewFlag(&cli.BoolFlag{
+			Name:        Reading,
+			EnvVars:     tgPrefix.EnvVars(Reading),
+			Destination: &opts.Reading,
+			Usage:       "Include the list of files that are read by components in the results (only when using --format=json).",
+		}),
 		flags.NewFlag(&cli.BoolFlag{
 			Name:        External,
 			EnvVars:     tgPrefix.EnvVars(External),
