@@ -1186,11 +1186,6 @@ func ParseConfigFile(ctx *ParsingContext, l log.Logger, configPath string, inclu
 			decodeListKey = fmt.Sprintf("%v", ctx.PartialParseDecodeList)
 		}
 
-		dir, err := os.Getwd()
-		if err != nil {
-			return err
-		}
-
 		fileInfo, err := os.Stat(configPath)
 		if err != nil {
 			if os.IsNotExist(err) {
@@ -1200,11 +1195,16 @@ func ParseConfigFile(ctx *ParsingContext, l log.Logger, configPath string, inclu
 			return errors.Errorf("failed to get file info: %w", err)
 		}
 
-		var (
-			file     *hclparse.File
-			cacheKey = fmt.Sprintf("parse-config-%v-%v-%v-%v-%v-%v", configPath, childKey, decodeListKey, ctx.TerragruntOptions.WorkingDir, dir, fileInfo.ModTime().UnixMicro())
+		cacheKey := fmt.Sprintf("%v-%v-%v-%v-%v",
+			configPath,
+			ctx.TerragruntOptions.WorkingDir,
+			childKey,
+			decodeListKey,
+			fileInfo.ModTime().UnixMicro(),
 		)
 
+		var file *hclparse.File
+
 		// TODO: Remove lint ignore
 		if cacheConfig, found := hclCache.Get(ctx, cacheKey); found { //nolint:contextcheck
 			file = cacheConfig
@@ -1282,7 +1282,7 @@ func ParseConfig(
 ) (*TerragruntConfig, error) {
 	errs := &errors.MultiError{}
 
-	if err := detectDeprecatedConfigurations(ctx, l, file); err != nil {
+	if err := DetectDeprecatedConfigurations(ctx, l, file); err != nil {
 		return nil, err
 	}
 
@@ -1370,20 +1370,12 @@ func ParseConfig(
 	return config, errs.ErrorOrNil()
 }
 
-// detectDeprecatedConfigurations detects if deprecated configurations are used in the given HCL file.
-func detectDeprecatedConfigurations(ctx *ParsingContext, l log.Logger, file *hclparse.File) error {
-	if detectInputsCtyUsage(file) {
-		allControls := ctx.TerragruntOptions.StrictControls
-
-		skipDependenciesInputs := allControls.Find(controls.SkipDependenciesInputs)
-		if skipDependenciesInputs == nil {
-			return errors.New("failed to find control " + controls.SkipDependenciesInputs)
-		}
-
-		evalCtx := log.ContextWithLogger(ctx, l)
-		if err := skipDependenciesInputs.Evaluate(evalCtx); err != nil {
-			return err
-		}
+// DetectDeprecatedConfigurations detects if deprecated configurations are used in the given HCL file.
+func DetectDeprecatedConfigurations(ctx *ParsingContext, l log.Logger, file *hclparse.File) error {
+	if DetectInputsCtyUsage(file) {
+		// Dependency inputs (dependency.foo.inputs.bar) are now blocked by default for performance.
+		// This deprecated feature causes significant performance overhead due to recursive parsing.
+		return errors.New("Reading inputs from dependencies is no longer supported. To acquire values from dependencies, use outputs (dependency.foo.outputs.bar) instead.")
 	}
 
 	if detectBareIncludeUsage(file) {
@@ -1403,10 +1395,10 @@ func detectDeprecatedConfigurations(ctx *ParsingContext, l log.Logger, file *hcl
 	return nil
 }
 
-// detectInputsCtyUsage detects if an identifier matching dependency.foo.inputs.bar is used in the given HCL file.
+// DetectInputsCtyUsage detects if an identifier matching dependency.foo.inputs.bar is used in the given HCL file.
 //
 // This is deprecated functionality, so we look for this to determine if we should throw an error or warning.
-func detectInputsCtyUsage(file *hclparse.File) bool {
+func DetectInputsCtyUsage(file *hclparse.File) bool {
 	body, ok := file.Body.(*hclsyntax.Body)
 	if !ok {
 		return false
